@@ -37,6 +37,7 @@
 #include <KJobWidgets>
 #include <KMimeTypeTrader>
 #include <KNewFileMenu>
+#include <KPluginMetaData>
 #include <KService>
 #include <KLocalizedString>
 #include <KStandardAction>
@@ -503,6 +504,7 @@ void DolphinContextMenu::addFileItemPluginActions()
     const KConfig config(QStringLiteral("kservicemenurc"), KConfig::NoGlobals);
     const KConfigGroup showGroup = config.group("Show");
 
+    QSet<QString> addedPlugins;
     foreach (const KService::Ptr& service, pluginServices) {
         if (!showGroup.readEntry(service->desktopEntryName(), true)) {
             // The plugin has been disabled
@@ -510,6 +512,30 @@ void DolphinContextMenu::addFileItemPluginActions()
         }
 
         KAbstractFileItemActionPlugin* abstractPlugin = service->createInstance<KAbstractFileItemActionPlugin>();
+        if (abstractPlugin) {
+            abstractPlugin->setParent(this);
+            addActions(abstractPlugin->actions(props, m_mainWindow));
+            addedPlugins << service->desktopEntryName();
+        }
+    }
+
+    const auto jsonPlugins = KPluginLoader::findPlugins(QStringLiteral("kf5/kfileitemaction"), [](const KPluginMetaData& metaData) {
+        return metaData.serviceTypes().contains(QStringLiteral("KFileItemAction/Plugin"));
+    });
+
+    foreach (const auto& jsonMetadata, jsonPlugins) {
+        // The plugin has been disabled
+        if (!showGroup.readEntry(jsonMetadata.pluginId(), true)) {
+            continue;
+        }
+
+        // The plugin also has a .desktop file and has already been added.
+        if (addedPlugins.contains(jsonMetadata.pluginId())) {
+            continue;
+        }
+
+        KPluginFactory *factory = KPluginLoader(jsonMetadata.fileName()).factory();
+        KAbstractFileItemActionPlugin* abstractPlugin = factory->create<KAbstractFileItemActionPlugin>();
         if (abstractPlugin) {
             abstractPlugin->setParent(this);
             addActions(abstractPlugin->actions(props, m_mainWindow));
